@@ -21,7 +21,6 @@
 #include <QUrlQuery>
 #include <QUuid>
 
-#include <KGAPI/Account>
 #include <KGAPI/AuthJob>
 #include <KGAPI/Drive/About>
 #include <KGAPI/Drive/AboutFetchJob>
@@ -207,9 +206,9 @@ KIO::UDSEntry KIOGDrive::fileToUDSEntry(const FilePtr &origFile, const QString &
         entry.fastInsert(KIO::UDSEntry::UDS_URL, fileToUrl(origFile, path).toString());
     }
 
-    entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, file->createdDate().toTime_t());
-    entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, file->modifiedDate().toTime_t());
-    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS_TIME, file->lastViewedByMeDate().toTime_t());
+    entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, file->createdDate().toSecsSinceEpoch());
+    entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, file->modifiedDate().toSecsSinceEpoch());
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS_TIME, file->lastViewedByMeDate().toSecsSinceEpoch());
     if (!file->ownerNames().isEmpty()) {
         entry.fastInsert(KIO::UDSEntry::UDS_USER, file->ownerNames().first());
     }
@@ -328,7 +327,7 @@ void KIOGDrive::listAccounts()
         return;
     }
 
-    Q_FOREACH (const QString &account, accounts) {
+    for (const QString &account : accounts) {
         const KIO::UDSEntry entry = accountToUDSEntry(account);
         listEntry(entry);
     }
@@ -740,8 +739,8 @@ void KIOGDrive::listDir(const QUrl &url)
         return;
     }
 
-    ObjectsList objects = fileFetchJob.items();
-    Q_FOREACH (const ObjectPtr &object, objects) {
+    const ObjectsList objects = fileFetchJob.items();
+    for (const ObjectPtr &object : objects) {
         const FilePtr file = object.dynamicCast<File>();
 
         const KIO::UDSEntry entry = fileToUDSEntry(file, url.adjusted(QUrl::StripTrailingSlash).path());
